@@ -30,13 +30,18 @@ Updraft Library
 
 def get_services_yaml_from_tag(updraft_tag, apps_only=True):
     remote_services_yaml = REMOTE_TEMPLATES_PATH + updraft_tag + "/services.yaml"
-    out = run_cmd(f"wget -qO- {remote_services_yaml}", silent=True)
-    services = yaml.safe_load(out)
-    services["services"] = {
-        s: v
-        for s, v in services["services"].items()
-        if v.get("group", None) not in ("static", "configs") and "nginx" not in s
-    }
+    out = run_cmd(f"wget -qO- {remote_services_yaml} 2>&1", silent=True)
+    try:
+        services = yaml.safe_load(out)
+    except Exception:
+        secho(f"Updraft version {updraft_tag} does not exist", fg="red")
+        return None
+    if apps_only:
+        services["services"] = {
+            s: v
+            for s, v in services["services"].items()
+            if v.get("group", None) not in ("static", "configs") and "nginx" not in s
+        }
     return services
 
 
@@ -132,14 +137,15 @@ class ClusterManager(object):
     def clean_services(self):
         updates = {}
         if "services" in self.cluster_config:
-            services = {k: v for k, v in deepcopy(self.cluster_config["services"]).items() if v.get("values", {}).get("image")}
+            services = {}
             unneeded = []
             for svc, val in self.cluster_config["services"].items():
-                if "image" not in val.get("values", {}):
+                if "values" not in val:
                     continue
-                del val["values"]["image"]
-                val["values"].pop("updated_at", None)
-                val["values"].pop("updated_by", None)
+                keys_to_migrate = [k for k in ("image", "updated_by", "updated_at") if k in val["values"]]
+                if keys_to_migrate:
+                    services[svc] = {"values": {k: val["values"].pop(k) for k in keys_to_migrate}}
+
                 # we don't want empty values floating around either
                 if not val["values"]:
                     del val["values"]
