@@ -3,7 +3,7 @@ from pathlib import Path
 
 import click
 
-from indico_install.cluster_manager import ClusterManager
+from indico_install.cluster_manager import ClusterManager, get_services_yaml_from_tag
 from indico_install.config import merge_dicts, yaml
 from indico_install.helm.apply import apply
 from indico_install.helm.render import render
@@ -59,6 +59,19 @@ def list_versions(ctx, number=None, ordered=False, regex=None):
     click.secho("\n".join(results))
 
 
+@updraft.command("cat")
+@click.pass_context
+@click.argument("version", required=False)
+def cat_version(ctx, version=None):
+    """
+    Show the service list for the provided VERSION (default: current cluster version)
+    """
+    version = string_to_tag(version) or ClusterManager().indico_version
+    services = get_services_yaml_from_tag(version, apps_only=False)
+    if services:
+        click.echo(yaml.dump(services, default_flow_style=False))
+
+
 @updraft.command("version")
 @click.pass_context
 def show_version(ctx):
